package Bundle::Catalyst;

use strict;

our $VERSION = '0.05';

=head1 NAME

Bundle::Catalyst - All you need to start with Catalyst

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Catalyst'>

=head1 DESCRIPTION

Installs everything you need to write serious Catalyst applications.

=head1 CONTENTS

Catalyst

Catalyst::Plugin::FormValidator

Catalyst::Plugin::FormValidator::Simple

Catalyst::Plugin::FillInForm

Catalyst::Plugin::Prototype

Catalyst::Plugin::Singleton

Catalyst::Plugin::DefaultEnd

Catalyst::Plugin::SubRequest

Catalyst::Plugin::Session

Catalyst::Plugin::Session::Store::File

Catalyst::Plugin::Session::State::Cookie

Catalyst::Plugin::Session::State::URI

Catalyst::Model::DBIC::Plain

Catalyst::Model::DBIC

Catalyst::View::TT

Test::WWW::Mechanize::Catalyst

DBD::SQLite

=head1 AUTHOR

Sebastian Riedel, C<sri@oook.de>

=head1 LICENSE

This library is free software. You can redistribute it and/or modify it under
the same terms as perl itself.

=cut

1;
